<?php


namespace App\Http\Controllers\Pdd;


use App\Http\Controllers\BaseController;
use App\Http\Logic\Pdd\PddLogic;

class PddController extends BaseController
{

    /**
     * @SWG\Get(
     *     path="/pdd/cate/list",
     *     tags={"拼多多导购管理"},
     *     summary="类目/活动/频道接口",
     *     description="类目/活动/频道接口",
     *     produces={"application/json"},
     *     @SWG\Response(
     *         response="200",
     *         description="success",
     *          @SWG\Schema(
     *              @SWG\Property(
     *                  property="cate",
     *                  type="array",
     *                  description="类目",
     *                  @SWG\Items(
     *                      @SWG\Property(
     *                          property="id",
     *                          type="string",
     *                          description="id"
     *                      ),
     *                      @SWG\Property(
     *                          property="name",
     *                          type="string",
     *                          description="名称"
     *                      )
     *                  )
     *              ),
     *              @SWG\Property(
     *                  property="activity",
     *                  type="array",
     *                  description="活动",
     *                  @SWG\Items(
     *                      @SWG\Property(
     *                          property="id",
     *                          type="string",
     *                          description="id"
     *                      ),
     *                      @SWG\Property(
     *                          property="name",
     *                          type="string",
     *                          description="名称"
     *                      )
     *                  )
     *              ),
     *              @SWG\Property(
     *                  property="channel",
     *                  type="array",
     *                  description="频道",
     *                  @SWG\Items(
     *                      @SWG\Property(
     *                          property="id",
     *                          type="string",
     *                          description="id"
     *                      ),
     *                      @SWG\Property(
     *                          property="name",
     *                          type="string",
     *                          description="名称"
     *                      )
     *                  )
     *              )
     *          )
     *     ),
     *     @SWG\Response(
     *         response="403",
     *         description="fail",
     *         @SWG\Schema(ref="#/definitions/ErrorBean")
     *     )
     * )
     */
    public function getCateList()
    {
        $datas = PddLogic::getCateListLogic();
        return $this->success($datas);
    }

    /**
     * @SWG\Get(
     *     path="/pdd/goods/list",
     *     tags={"拼多多导购管理"},
     *     summary="商品列表接口",
     *     description="商品列表接口",
     *     produces={"application/json"},
     *     @SWG\Parameter(
     *          name="page",
     *          in="query",
     *          description="第几页",
     *          type="string"
     *     ),
     *     @SWG\Parameter(
     *          name="activity_id",
     *          in="query",
     *          description="活动ID",
     *          type="string"
     *     ),
     *     @SWG\Parameter(
     *          name="cat_id",
     *          in="query",
     *          description="类目ID",
     *          type="string"
     *     ),
     *     @SWG\Parameter(
     *          name="channel_id",
     *          in="query",
     *          description="频道ID",
     *          type="string"
     *     ),
     *     @SWG\Response(
     *         response="200",
     *         description="success",
     *          @SWG\Schema(
     *              @SWG\Property(
     *                  property="total",
     *                  type="string",
     *                  description="数量"
     *              ),
     *              @SWG\Property(
     *                  property="list",
     *                  type="array",
     *                  description="数据",
     *                  @SWG\Items(
     *                      @SWG\Property(
     *                          property="goods_name",
     *                          type="string",
     *                          description="商品名称"
     *                      ),
     *                      @SWG\Property(
     *                          property="goods_desc",
     *                          type="string",
     *                          description="商品描述"
     *                      ),
     *                      @SWG\Property(
     *                          property="goods_image_url",
     *                          type="string",
     *                          description="商品主图"
     *                      ),
     *                      @SWG\Property(
     *                          property="goods_sign",
     *                          type="string",
     *                          description="商品ID"
     *                      ),
     *                      @SWG\Property(
     *                          property="goods_thumbnail_url",
     *                          type="string",
     *                          description="商品缩略图"
     *                      ),
     *                      @SWG\Property(
     *                          property="mall_name",
     *                          type="string",
     *                          description="店铺名称"
     *                      ),
     *                      @SWG\Property(
     *                          property="promotion_rate",
     *                          type="string",
     *                          description="佣金比例,千分比"
     *                      ),
     *                      @SWG\Property(
     *                          property="sales_tip",
     *                          type="string",
     *                          description="销售量"
     *                      )
     *                  )
     *              )
     *          )
     *     ),
     *     @SWG\Response(
     *         response="403",
     *         description="fail",
     *         @SWG\Schema(ref="#/definitions/ErrorBean")
     *     )
     * )
     */
    public function getGoodsList()
    {
        $datas = PddLogic::getGoodsListLogic();
        return $this->success($datas);
    }

    /**
     * @SWG\Get(
     *     path="/pdd/goods/recommendurl",
     *     tags={"拼多多导购管理"},
     *     summary="生成商品推广链接接口",
     *     description="生成商品推广链接接口",
     *     produces={"application/json"},
     *     @SWG\Parameter(
     *          name="goods_sign",
     *          in="query",
     *          description="商品ID",
     *          type="string"
     *     ),
     *     @SWG\Response(
     *         response="200",
     *         description="success",
     *          @SWG\Schema(
     *              @SWG\Property(
     *                  property="link_url",
     *                  type="string",
     *                  description="推广链接"
     *              )
     *          )
     *     ),
     *     @SWG\Response(
     *         response="403",
     *         description="fail",
     *         @SWG\Schema(ref="#/definitions/ErrorBean")
     *     )
     * )
     */
    public function getGoodsRecommendUrl()
    {
        $datas = PddLogic::getGoodsRecommendUrlLogic();
        return $this->success($datas);
    }
}