<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::middleware('auth:api')->get('/user', function (Request $request) {
    return $request->user();
});

//生成swagger.json文件
Route::get("/swagger","BaseController@swagger");
//读取swagger内容
Route::get("/loadswagger","BaseController@loadSwagger");
//测试
Route::get("/test","BaseController@test");



//校验微信服务器
Route::any("/checkServer/{code}","WechatController@checkServer");
//设置微信菜单
Route::get("/wechat/setmenu","WechatController@setMenu");
//获取微信
Route::get("/wechat/account/config","WechatController@accountConfig");
//微信公众号授权回调
Route::any("wechat/account/callback","WechatController@accountCallback");

//根据链接获取转链链接
Route::any("transfer/{userId}/{actId}","Home\HomeController@getTransferLinkurl");

//定时任务
Route::prefix("cron")->namespace("Cron")->group(function (){
   //获取美团订单
    Route::get("meituan/orders","CronController@meituanOrders");
    //获取聚推客订单
    Route::get("jutuike/orders","CronController@jutuikeOrders");
    //获取拼多多订单
    Route::get("pdd/orders","CronController@pddOrders");
    //下单提醒
    Route::get("send/order/template","CronController@sendOrderTemplate");
    //定时结算佣金
    Route::get("settlement/order","CronController@settlementOrderCommission");
    //定时处理提现
    Route::get("transfer/finance","CronController@transferFinance");
    //定时处理打款失败记录
    Route::get("callback/cash","CronController@callbackCash");
});

//用户管理
Route::prefix("user")->namespace("User")->middleware(["checkAuth"])->group(function (){
    //获取用户信息接口
    Route::get("info","UserController@getUserInfo");
    //获取用户粉丝
    Route::get("fans/list","UserController@getFansList");
    //收支明细列表
    Route::get("fianance/list","UserController@getFinanceList");
    //流水详情
    Route::get("fianance/detail","UserController@getFinanceDetail");
    //用户提现
    Route::post("cash","UserController@getCash");
    //获取用户推广二维码
    Route::get("recommend/url","UserController@getRecommendUrl");
});


//订单管理
Route::prefix("order")->namespace("Order")->middleware(["checkAuth"])->group(function (){
    //获取订单列表接口
    Route::get("list","OrderController@getOrderList");
    //获取订单类型接口
    Route::get("type/list","OrderController@getOrderTypeList");
    //订单详情接口
    Route::get("detail","OrderController@getOrderDetail");
});

//首页省钱
Route::prefix("home")->namespace("Home")->middleware(["checkAuth"])->group(function (){
    //获取省钱列表接口
    Route::get("list","HomeController@getHomeList");
    //返钱赚钱接口
    Route::get("commission/list","HomeController@getCommissionList");
});



//拼多多导购相关接口
Route::prefix("pdd")->namespace("Pdd")->middleware(["checkAuth"])->group(function (){
    //获取商品类目接口
    Route::get("cate/list","PddController@getCateList");
    //商品列表
    Route::get("goods/list","PddController@getGoodsList");
    //获取商品推广链接
    Route::get("goods/recommendurl","PddController@getGoodsRecommendUrl");
});


//电商相关接口
Route::prefix("buy")->namespace("Buy")->middleware(["checkAuth"])->group(function (){
    //获取商品类目接口
    Route::get("cate/list","BuyController@getCateList");
    //获取商品列表接口
    Route::post("goods/list","BuyController@getGoodsList");
    //获取商品详情页接口
    Route::get("goods/detail","BuyController@getGoodsDetail");
    //商品搜索接口
    Route::get("goods/search","BuyController@getGoodsSearch");
});









